# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveCommentReqUserIDType(object):
    pass


@attr.s
class GetDriveCommentReqFileType(object):
    pass


@attr.s
class GetDriveCommentReq(object):
    file_type: GetDriveCommentReqFileType = attr.ib(
        factory=lambda: GetDriveCommentReqFileType(), metadata={"req_type": "query"}
    )  # 文档类型, 示例值："doc", 可选值有: `doc`：文档, `sheet`：表格, `file`：文件
    user_id_type: GetDriveCommentReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    file_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文档token, 示例值："doccnHh7U87HOFpii5u5G*****"
    comment_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 评论ID, 示例值："6916106822734578184"


@attr.s
class GetDriveCommentRespReplyListReplyContentElementPerson(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复 at联系人


@attr.s
class GetDriveCommentRespReplyListReplyContentElementDocsLink(object):
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复 at云文档


@attr.s
class GetDriveCommentRespReplyListReplyContentElementTextRun(object):
    text: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复 普通文本


@attr.s
class GetDriveCommentRespReplyListReplyContentElement(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复的内容元素, 可选值有: `text_run`：普通文本, `docs_link`：at 云文档链接, `person`：at 联系人
    text_run: GetDriveCommentRespReplyListReplyContentElementTextRun = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容
    docs_link: GetDriveCommentRespReplyListReplyContentElementDocsLink = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容
    person: GetDriveCommentRespReplyListReplyContentElementPerson = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容


@attr.s
class GetDriveCommentRespReplyListReplyContent(object):
    elements: typing.List[GetDriveCommentRespReplyListReplyContentElement] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 回复的内容


@attr.s
class GetDriveCommentRespReplyListReply(object):
    reply_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复ID
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    update_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 更新时间
    content: GetDriveCommentRespReplyListReplyContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 回复内容


@attr.s
class GetDriveCommentRespReplyList(object):
    replies: typing.List[GetDriveCommentRespReplyListReply] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 回复列表


@attr.s
class GetDriveCommentResp(object):
    comment_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 评论ID
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    update_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 更新时间
    is_solved: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否已解决
    solved_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 解决评论时间
    solver_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 解决评论者的用户ID
    reply_list: GetDriveCommentRespReplyList = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 评论里的回复列表


def _gen_get_drive_comment_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveCommentResp,
        scope="Drive",
        api="GetDriveComment",
        method="GET",
        url="https://open.feishu.cn/open-apis/drive/v1/files/:file_token/comments/:comment_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetSheetProtectedDimensionReq(object):
    protect_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 保护范围ID，可以通过[获取表格元数据](https://open.feishu.cn/document/ukTMukTMukTM/uETMzUjLxEzM14SMxMTN)接口获取，多个ID用逗号分隔，如xxxID1,xxxID2
    member_type: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 返回的用户类型，可选userId,openId,unionId,默认使用userId
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)


@attr.s
class GetSheetProtectedDimensionRespProtectedRangeEditorsUser(object):
    member_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID


@attr.s
class GetSheetProtectedDimensionRespProtectedRangeEditors(object):
    users: typing.List[
        GetSheetProtectedDimensionRespProtectedRangeEditorsUser
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 用户信息列表


@attr.s
class GetSheetProtectedDimensionRespProtectedRangeDimension(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheet 的 id
    start_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 保护行列起始下标，下标从1开始
    end_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 保护行列终止下标，下标从1开始
    major_dimension: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 保护范围的维度，COLUMNS为保护列，ROWS为保护行


@attr.s
class GetSheetProtectedDimensionRespProtectedRange(object):
    protect_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 保护范围ID
    dimension: GetSheetProtectedDimensionRespProtectedRangeDimension = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 保护范围，如果为空，则为保护子表
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheet的id
    lock_info: str = attr.ib(default="", metadata={"req_type": "json"})  # 保护说明
    editors: GetSheetProtectedDimensionRespProtectedRangeEditors = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 用户信息


@attr.s
class GetSheetProtectedDimensionResp(object):
    protected_range: GetSheetProtectedDimensionRespProtectedRange = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 保护范围


def _gen_get_sheet_protected_dimension_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetSheetProtectedDimensionResp,
        scope="Drive",
        api="GetSheetProtectedDimension",
        method="GET",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/protected_range_batch_get",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class InitAttendanceRemedyApprovalReqEmployeeType(object):
    pass


@attr.s
class InitAttendanceRemedyApprovalReq(object):
    employee_type: InitAttendanceRemedyApprovalReqEmployeeType = attr.ib(
        factory=lambda: InitAttendanceRemedyApprovalReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 请求体中的 user_id 的员工工号类型，必选字段，可用值：【employee_id（员工employeeId），employee_no（员工工号）】，示例值："employee_id"
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 ID
    remedy_date: int = attr.ib(default=0, metadata={"req_type": "json"})  # 补卡日期
    punch_no: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 第几次上下班，可用值【0（第 1 次上下班），1（第 2 次上下班），2（第 3 次上下班）】，自由班次时填 0
    work_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 上班/下班，1：上班，2：下班，自由班次时填 0
    remedy_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 补卡时间，时间格式为 yyyy-MM-dd HH:mm
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 补卡原因


@attr.s
class InitAttendanceRemedyApprovalRespUserRemedy(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 ID
    approval_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批实例 ID，可用于通知审批状态更新
    remedy_date: int = attr.ib(default=0, metadata={"req_type": "json"})  # 补卡日期
    punch_no: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 第几次上下班，可用值【0（第 1 次上下班），1（第2次上下班），2（第3次上下班）】，自由班次时填 0
    work_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 上班/下班，1：上班，2：下班
    remedy_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 补卡时间，时间格式为 yyyy-MM-dd HH:mm
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 补卡原因


@attr.s
class InitAttendanceRemedyApprovalResp(object):
    user_remedy: InitAttendanceRemedyApprovalRespUserRemedy = attr.ib(
        default=None, metadata={"req_type": "json"}
    )


def _gen_init_attendance_remedy_approval_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=InitAttendanceRemedyApprovalResp,
        scope="Attendance",
        api="InitAttendanceRemedyApproval",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_task_remedys",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class MoveSheetDimensionReqSource(object):
    major_dimension: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 操作行还是列，取值：ROWS、COLUMNS, 示例值："ROWS"
    start_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 起始行或者列号, 示例值：0
    end_index: int = attr.ib(default=0, metadata={"req_type": "json"})  # 结束行或者列号, 示例值：1


@attr.s
class MoveSheetDimensionReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 表格 token, 示例值："shtcnmBA\*****yGehy8"
    sheet_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 子表 id, 示例值："0b\**12"
    source: MoveSheetDimensionReqSource = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 移动源位置参数
    destination_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 移动的目标位置行或者列号, 示例值：4


@attr.s
class MoveSheetDimensionResp(object):
    pass


def _gen_move_sheet_dimension_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=MoveSheetDimensionResp,
        scope="Drive",
        api="MoveSheetDimension",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v3/spreadsheets/:spreadsheet_token/sheets/:sheet_id/move_dimension",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskAgentScheduleReq(object):
    agent_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 客服 id, 示例值："	客服 id"


@attr.s
class GetHelpdeskAgentScheduleRespAgentScheduleAgentSkill(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 客服技能 id
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 客服技能名
    is_default: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是默认技能


@attr.s
class GetHelpdeskAgentScheduleRespAgentScheduleSchedule(object):
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间, format 00:00 - 23:59
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间, format 00:00 - 23:59
    weekday: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 星期几, 1 - Monday, 2 - Tuesday, 3 - Wednesday, 4 - Thursday, 5 - Friday, 6 - Saturday, 7 - Sunday, 9 - Everday, 10 - Weekday, 11 - Weekend


@attr.s
class GetHelpdeskAgentScheduleRespAgentScheduleAgent(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 客服 id
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # avatar url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 客服名字
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # email
    department: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门
    company_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 公司名


@attr.s
class GetHelpdeskAgentScheduleRespAgentSchedule(object):
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 客服状态, 1 - online客服, 2 - offline(手动)客服, 3 - off duty(下班)自动处于非服务时间段
    agent: GetHelpdeskAgentScheduleRespAgentScheduleAgent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 客服信息
    schedule: GetHelpdeskAgentScheduleRespAgentScheduleSchedule = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工作日程列表
    agent_skills: typing.List[
        GetHelpdeskAgentScheduleRespAgentScheduleAgentSkill
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 客服技能


@attr.s
class GetHelpdeskAgentScheduleResp(object):
    agent_schedule: GetHelpdeskAgentScheduleRespAgentSchedule = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 客服日程


def _gen_get_helpdesk_agent_schedule_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskAgentScheduleResp,
        scope="Helpdesk",
        api="GetHelpdeskAgentSchedule",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/agents/:agent_id/schedules",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io
from pylark.type_message_post import MessageContentPostAll


@attr.s
class SendRawMessageOldReqContent(object):
    text: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文本消息内容，文本消息中可以 at 个人或全体成员<br>at 全体成员：<at user_id="all">  </at> <br> at 个人：<at user_id="ou_xxxxxxx"></at>，user_id 为用户 user_id或者open_id
    post: MessageContentPostAll = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 富文本消息


@attr.s
class SendRawMessageOldReqMsgType(object):
    pass


@attr.s
class SendRawMessageOldReq(object):
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 给用户发私聊消息，只需要填 open_id、email、user_id 中的一个即可，向群里发消息使用群的 chat_id。服务端依次读取字段的顺序为 chat_id > open_id > user_id > email   ( user_id 对应V3接口的 employee_id , chat_id 对应V3的 open_chat_id )
    open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 给用户发私聊消息，只需要填 open_id、email、user_id 中的一个即可，向群里发消息使用群的 chat_id。服务端依次读取字段的顺序为 chat_id > open_id > user_id > email   ( user_id 对应V3接口的 employee_id , chat_id 对应V3的 open_chat_id )
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 给用户发私聊消息，只需要填 open_id、email、user_id 中的一个即可，向群里发消息使用群的 chat_id。服务端依次读取字段的顺序为 chat_id > open_id > user_id > email   ( user_id 对应V3接口的 employee_id , chat_id 对应V3的 open_chat_id )
    email: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 给用户发私聊消息，只需要填 open_id、email、user_id 中的一个即可，向群里发消息使用群的 chat_id。服务端依次读取字段的顺序为 chat_id > open_id > user_id > email   ( user_id 对应V3接口的 employee_id , chat_id 对应V3的 open_chat_id )
    root_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 如果需要回复某条消息，填对应消息的消息 ID
    msg_type: SendRawMessageOldReqMsgType = attr.ib(
        factory=lambda: SendRawMessageOldReqMsgType(), metadata={"req_type": "json"}
    )  # 消息类型，此处固定填 "text"
    content: SendRawMessageOldReqContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息内容


@attr.s
class SendRawMessageOldResp(object):
    message_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 消息 ID


def _gen_send_raw_message_old_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=SendRawMessageOldResp,
        scope="Message",
        api="SendRawMessageOld",
        method="POST",
        url="https://open.feishu.cn/open-apis/message/v4/send/",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class SendHelpdeskTicketMessageReqMsgType(object):
    pass


@attr.s
class SendHelpdeskTicketMessageReq(object):
    ticket_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 工单ID, 示例值："6948728206392295444"
    msg_type: SendHelpdeskTicketMessageReqMsgType = attr.ib(
        factory=lambda: SendHelpdeskTicketMessageReqMsgType(),
        metadata={"req_type": "json"},
    )  # 消息类型；text：纯文本；post：富文本, 示例值："post"
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # - 纯文本，参考[发送文本消息](https://open.feishu.cn/document/ukTMukTMukTM/uUjNz4SN2MjL1YzM)中的content；, 富文本，参考[发送富文本消息](https://open.feishu.cn/document/ukTMukTMukTM/uMDMxEjLzATMx4yMwETM)中的content, 示例值："{,        "post": {,            "zh_cn": {,                "title": "this is title",,                "content": [,                    [,                        {,                            "tag": "text",,                            "un_escape": true,,                            "text": "第一行&nbsp;:",                        },,                        {,                            "tag": "a",,                            "text": "超链接",,                            "href": "http://www.feishu.cn",                        },                    ],,                    [,                        {,                            "tag": "text",,                            "text": "第二行 :",                        },,                        {,                            "tag": "text",,                            "text": "文本测试",                        },                    ],                ],            },        },    }"


@attr.s
class SendHelpdeskTicketMessageResp(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # chat消息open ID


def _gen_send_helpdesk_ticket_message_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=SendHelpdeskTicketMessageResp,
        scope="Helpdesk",
        api="SendHelpdeskTicketMessage",
        method="POST",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/tickets/:ticket_id/messages",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateHelpdeskFAQReqFAQ(object):
    category_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 知识库分类ID, 示例值："6836004780707807251"
    question: str = attr.ib(default="", metadata={"req_type": "json"})  # 问题, 示例值："问题"
    answer: str = attr.ib(default="", metadata={"req_type": "json"})  # 答案, 示例值："答案"
    answer_richtext: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 富文本答案和答案必须有一个必填。Json Array格式，富文本结构请见[了解更多: 富文本](https://open.feishu.cn/document/ukTMukTMukTM/uITM0YjLyEDN24iMxQjN), 示例值："[{,                        "content": "这只是一个测试，医保问题",,                        "type": "text",                    }]"
    tags: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 关联词


@attr.s
class UpdateHelpdeskFAQReq(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 知识库ID, 示例值："6856395634652479491"
    faq: UpdateHelpdeskFAQReqFAQ = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 修改的知识库内容


@attr.s
class UpdateHelpdeskFAQResp(object):
    pass


def _gen_update_helpdesk_faq_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateHelpdeskFAQResp,
        scope="Helpdesk",
        api="UpdateHelpdeskFAQ",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/faqs/:id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskTicketCustomizedFieldReq(object):
    ticket_customized_field_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 工单自定义字段ID, 示例值："6948728206392295444"


@attr.s
class GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptionsChildrenChildren(
    object
):
    pass


@attr.s
class GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptionsChildren(object):
    tag: str = attr.ib(default="", metadata={"req_type": "json"})  # 选项ID
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 展示名称
    children: typing.List[
        GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptionsChildrenChildren
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 同上：选项列表，只适用于多层下拉列表（最多可以设置三级下拉列表）


@attr.s
class GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptions(object):
    children: GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptionsChildren = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 选项列表


@attr.s
class GetHelpdeskTicketCustomizedFieldRespUpdatedBy(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱
    dropdown_options: GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptions = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 下拉列表选项


@attr.s
class GetHelpdeskTicketCustomizedFieldRespCreatedBy(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱


@attr.s
class GetHelpdeskTicketCustomizedFieldResp(object):
    ticket_customized_field_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 工单自定义字段ID
    helpdesk_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 服务台ID
    key_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 键名
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    position: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 字段在列表后台管理列表中的位置
    field_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 类型
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 描述
    visible: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否可见
    editable: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否可以修改
    required: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否必填
    created_at: str = attr.ib(default="", metadata={"req_type": "json"})  # 创建时间
    updated_at: str = attr.ib(default="", metadata={"req_type": "json"})  # 更新时间
    created_by: GetHelpdeskTicketCustomizedFieldRespCreatedBy = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 创建用户
    updated_by: GetHelpdeskTicketCustomizedFieldRespUpdatedBy = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 更新用户
    dropdown_allow_multiple: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否支持多选，仅在字段类型是dropdown的时候有效


def _gen_get_helpdesk_ticket_customized_field_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskTicketCustomizedFieldResp,
        scope="Helpdesk",
        api="GetHelpdeskTicketCustomizedField",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/ticket_customized_fields/:ticket_customized_field_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_vc_reserve_apply import (
    ApplyVCReserveReq,
    ApplyVCReserveResp,
    _gen_apply_vc_reserve_req,
)
from pylark.api_service_vc_reserve_update import (
    UpdateVCReserveReq,
    UpdateVCReserveResp,
    _gen_update_vc_reserve_req,
)
from pylark.api_service_vc_reserve_delete import (
    DeleteVCReserveReq,
    DeleteVCReserveResp,
    _gen_delete_vc_reserve_req,
)
from pylark.api_service_vc_reserve_get import (
    GetVCReserveReq,
    GetVCReserveResp,
    _gen_get_vc_reserve_req,
)
from pylark.api_service_vc_reserve_get_active_meeting import (
    GetVCReserveActiveMeetingReq,
    GetVCReserveActiveMeetingResp,
    _gen_get_vc_reserve_active_meeting_req,
)
from pylark.api_service_vc_meeting_get import (
    GetVCMeetingReq,
    GetVCMeetingResp,
    _gen_get_vc_meeting_req,
)
from pylark.api_service_vc_meeting_invite import (
    InviteVCMeetingReq,
    InviteVCMeetingResp,
    _gen_invite_vc_meeting_req,
)
from pylark.api_service_vc_meeting_set_host import (
    SetVCHostMeetingReq,
    SetVCHostMeetingResp,
    _gen_set_vc_host_meeting_req,
)
from pylark.api_service_vc_meeting_end import (
    EndVCMeetingReq,
    EndVCMeetingResp,
    _gen_end_vc_meeting_req,
)
from pylark.api_service_vc_meeting_recording_start import (
    StartVCMeetingRecordingReq,
    StartVCMeetingRecordingResp,
    _gen_start_vc_meeting_recording_req,
)
from pylark.api_service_vc_meeting_recording_stop import (
    StopVCMeetingRecordingReq,
    StopVCMeetingRecordingResp,
    _gen_stop_vc_meeting_recording_req,
)
from pylark.api_service_vc_meeting_recording_get import (
    GetVCMeetingRecordingReq,
    GetVCMeetingRecordingResp,
    _gen_get_vc_meeting_recording_req,
)
from pylark.api_service_vc_meeting_recording_set_permission import (
    SetVCPermissionMeetingRecordingReq,
    SetVCPermissionMeetingRecordingResp,
    _gen_set_vc_permission_meeting_recording_req,
)
from pylark.api_service_vc_report_get_daily import (
    GetVCDailyReportReq,
    GetVCDailyReportResp,
    _gen_get_vc_daily_report_req,
)
from pylark.api_service_vc_report_get_top_user import (
    GetVCTopUserReportReq,
    GetVCTopUserReportResp,
    _gen_get_vc_top_user_report_req,
)
from pylark.api_service_vc_room_config_get import (
    GetVCRoomConfigReq,
    GetVCRoomConfigResp,
    _gen_get_vc_room_config_req,
)
from pylark.api_service_vc_room_config_set import (
    SetVCRoomConfigReq,
    SetVCRoomConfigResp,
    _gen_set_vc_room_config_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkVCService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def apply_vc_reserve(
        self, request: ApplyVCReserveReq, options: typing.List[str] = None
    ) -> typing.Tuple[ApplyVCReserveResp, Response]:
        return self.cli.raw_request(_gen_apply_vc_reserve_req(request, options))

    def update_vc_reserve(
        self, request: UpdateVCReserveReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateVCReserveResp, Response]:
        return self.cli.raw_request(_gen_update_vc_reserve_req(request, options))

    def delete_vc_reserve(
        self, request: DeleteVCReserveReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteVCReserveResp, Response]:
        return self.cli.raw_request(_gen_delete_vc_reserve_req(request, options))

    def get_vc_reserve(
        self, request: GetVCReserveReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetVCReserveResp, Response]:
        return self.cli.raw_request(_gen_get_vc_reserve_req(request, options))

    def get_vc_reserve_active_meeting(
        self, request: GetVCReserveActiveMeetingReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetVCReserveActiveMeetingResp, Response]:
        return self.cli.raw_request(
            _gen_get_vc_reserve_active_meeting_req(request, options)
        )

    def get_vc_meeting(
        self, request: GetVCMeetingReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetVCMeetingResp, Response]:
        return self.cli.raw_request(_gen_get_vc_meeting_req(request, options))

    def invite_vc_meeting(
        self, request: InviteVCMeetingReq, options: typing.List[str] = None
    ) -> typing.Tuple[InviteVCMeetingResp, Response]:
        return self.cli.raw_request(_gen_invite_vc_meeting_req(request, options))

    def set_vc_host_meeting(
        self, request: SetVCHostMeetingReq, options: typing.List[str] = None
    ) -> typing.Tuple[SetVCHostMeetingResp, Response]:
        return self.cli.raw_request(_gen_set_vc_host_meeting_req(request, options))

    def end_vc_meeting(
        self, request: EndVCMeetingReq, options: typing.List[str] = None
    ) -> typing.Tuple[EndVCMeetingResp, Response]:
        return self.cli.raw_request(_gen_end_vc_meeting_req(request, options))

    def start_vc_meeting_recording(
        self, request: StartVCMeetingRecordingReq, options: typing.List[str] = None
    ) -> typing.Tuple[StartVCMeetingRecordingResp, Response]:
        return self.cli.raw_request(
            _gen_start_vc_meeting_recording_req(request, options)
        )

    def stop_vc_meeting_recording(
        self, request: StopVCMeetingRecordingReq, options: typing.List[str] = None
    ) -> typing.Tuple[StopVCMeetingRecordingResp, Response]:
        return self.cli.raw_request(
            _gen_stop_vc_meeting_recording_req(request, options)
        )

    def get_vc_meeting_recording(
        self, request: GetVCMeetingRecordingReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetVCMeetingRecordingResp, Response]:
        return self.cli.raw_request(_gen_get_vc_meeting_recording_req(request, options))

    def set_vc_permission_meeting_recording(
        self,
        request: SetVCPermissionMeetingRecordingReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[SetVCPermissionMeetingRecordingResp, Response]:
        return self.cli.raw_request(
            _gen_set_vc_permission_meeting_recording_req(request, options)
        )

    def get_vc_daily_report(
        self, request: GetVCDailyReportReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetVCDailyReportResp, Response]:
        return self.cli.raw_request(_gen_get_vc_daily_report_req(request, options))

    def get_vc_top_user_report(
        self, request: GetVCTopUserReportReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetVCTopUserReportResp, Response]:
        return self.cli.raw_request(_gen_get_vc_top_user_report_req(request, options))

    def get_vc_room_config(
        self, request: GetVCRoomConfigReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetVCRoomConfigResp, Response]:
        return self.cli.raw_request(_gen_get_vc_room_config_req(request, options))

    def set_vc_room_config(
        self, request: SetVCRoomConfigReq, options: typing.List[str] = None
    ) -> typing.Tuple[SetVCRoomConfigResp, Response]:
        return self.cli.raw_request(_gen_set_vc_room_config_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApplicationOrderListReq(object):
    status: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 获取用户购买套餐信息设置的过滤条件, normal为正常状态，refunded为已退款，该字段为空或者all表示所有，未支付的订单无法查到
    page_size: int = attr.ib(default=0, metadata={"req_type": "query"})  # `每页显示的订单数量`
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 翻页标识，可以从上次请求的响应中获取，不填或者为空时表示从开头获取
    tenant_key: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 购买应用的租户唯一标识，为空表示获取应用下所有订单，有值表示获取应用下该租户购买的订单


@attr.s
class GetApplicationOrderListRespOrderList(object):
    order_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 订单ID，唯一标识
    price_plan_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 价格方案ID，唯一标识
    price_plan_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 价格方案类型 "trial" -试用；"permanent"-一次性付费；"per_year"-企业年付费；"per_month"-企业月付费；"per_seat_per_year"-按人按年付费；"per_seat_per_month"-按人按月付费；"permanent_count"-按次付费；
    seats: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 实际购买人数 仅对price_plan_type为per_seat_per_year和per_seat_per_month 有效
    buy_count: int = attr.ib(default=0, metadata={"req_type": "json"})  # 购买数量 总是为1
    create_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 订单创建时间戳
    pay_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 订单支付时间戳
    status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 订单当前状态，"normal" -正常；"refund"-已退款；
    buy_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 购买类型，"buy" - 普通购买;"upgrade"-为升级购买(仅price_plan_type 为per_year，per_month，per_seat_per_year，per_seat_per_month时可升级购买);"renew" - 续费购买；
    src_order_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 源订单ID，当前订单为升级购买时，即buy_type为upgrade时，此字段记录源订单等ID
    dst_order_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 升级后的新订单ID，当前订单如果做过升级购买，此字段记录升级购买后生成的新订单ID，当前订单仍然有效
    order_pay_price: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 订单实际支付金额, 单位分
    tenant_key: str = attr.ib(default="", metadata={"req_type": "json"})  # 租户唯一标识


@attr.s
class GetApplicationOrderListResp(object):
    total: int = attr.ib(default=0, metadata={"req_type": "json"})  # 总订单数
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有数据，true还有数据，false没有数据
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 下一页数据的标识，可作为请求下一页数据的参数，当has_more为false时该字段为空
    order_list: GetApplicationOrderListRespOrderList = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 订单信息列表


def _gen_get_application_order_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApplicationOrderListResp,
        scope="Application",
        api="GetApplicationOrderList",
        method="GET",
        url="https://open.feishu.cn/open-apis/pay/v1/order/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class IsInChatReq(object):
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 群 ID, 示例值: "oc_a0553eda9014c201e6969b478895c230"


@attr.s
class IsInChatResp(object):
    is_in_chat: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 用户或者机器人是否在群中


def _gen_is_in_chat_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=IsInChatResp,
        scope="Chat",
        api="IsInChat",
        method="GET",
        url="https://open.feishu.cn/open-apis/im/v1/chats/:chat_id/members/is_in_chat",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_human_auth_face_verify_get_auth_result import (
    GetFaceVerifyAuthResultReq,
    GetFaceVerifyAuthResultResp,
    _gen_get_face_verify_auth_result_req,
)
from pylark.api_service_human_auth_face_verify_upload_image import (
    UploadFaceVerifyImageReq,
    UploadFaceVerifyImageResp,
    _gen_upload_face_verify_image_req,
)
from pylark.api_service_human_auth_face_verify_crop_image import (
    CropFaceVerifyImageReq,
    CropFaceVerifyImageResp,
    _gen_crop_face_verify_image_req,
)
from pylark.api_service_human_auth_identity import (
    CreateIdentityReq,
    CreateIdentityResp,
    _gen_create_identity_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkHumanAuthService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_face_verify_auth_result(
        self, request: GetFaceVerifyAuthResultReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetFaceVerifyAuthResultResp, Response]:
        return self.cli.raw_request(
            _gen_get_face_verify_auth_result_req(request, options)
        )

    def upload_face_verify_image(
        self, request: UploadFaceVerifyImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[UploadFaceVerifyImageResp, Response]:
        return self.cli.raw_request(_gen_upload_face_verify_image_req(request, options))

    def crop_face_verify_image(
        self, request: CropFaceVerifyImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[CropFaceVerifyImageResp, Response]:
        return self.cli.raw_request(_gen_crop_face_verify_image_req(request, options))

    def create_identity(
        self, request: CreateIdentityReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateIdentityResp, Response]:
        return self.cli.raw_request(_gen_create_identity_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class TransferApprovalInstanceReq(object):
    approval_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义 Code
    instance_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例 Code
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 操作用户
    task_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 任务 ID
    comment: str = attr.ib(default="", metadata={"req_type": "json"})  # 意见
    transfer_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 被转交人唯一 ID
    open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户open_id <br>如果没有user_id，必须要有open_id
    transfer_open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 被转交人open_id <br>如果没有transfer_user_id，必须要有transfer_open_id


@attr.s
class TransferApprovalInstanceResp(object):
    pass


def _gen_transfer_approval_instance_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=TransferApprovalInstanceResp,
        scope="Approval",
        api="TransferApprovalInstance",
        method="POST",
        url="https://www.feishu.cn/approval/openapi/v2/instance/transfer",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateUpdateAttendanceUserDailyShiftReqUserDailyShift(object):
    group_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 考勤组 ID
    shift_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 班次 ID，休息为 0
    month: int = attr.ib(default=0, metadata={"req_type": "json"})  # 月份
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户
    day_no: int = attr.ib(default=0, metadata={"req_type": "json"})  # 日期


@attr.s
class CreateUpdateAttendanceUserDailyShiftReqEmployeeType(object):
    pass


@attr.s
class CreateUpdateAttendanceUserDailyShiftReq(object):
    employee_type: CreateUpdateAttendanceUserDailyShiftReqEmployeeType = attr.ib(
        factory=lambda: CreateUpdateAttendanceUserDailyShiftReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 请求体中的 user_id 的员工工号类型可用值：【employee_id（员工的 employeeId），employee_no（员工工号）】，示例值："employee_id"
    user_daily_shifts: typing.List[
        CreateUpdateAttendanceUserDailyShiftReqUserDailyShift
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 班表信息列表


@attr.s
class CreateUpdateAttendanceUserDailyShiftRespUserDailyShift(object):
    group_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 考勤组 ID
    shift_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 班次 ID
    month: int = attr.ib(default=0, metadata={"req_type": "json"})  # 月份
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户
    day_no: int = attr.ib(default=0, metadata={"req_type": "json"})  # 日期


@attr.s
class CreateUpdateAttendanceUserDailyShiftResp(object):
    user_daily_shifts: typing.List[
        CreateUpdateAttendanceUserDailyShiftRespUserDailyShift
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 班表信息列表


def _gen_create_update_attendance_user_daily_shift_req(
    request, options
) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateUpdateAttendanceUserDailyShiftResp,
        scope="Attendance",
        api="CreateUpdateAttendanceUserDailyShift",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_daily_shifts/batch_create",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateTaskCollaboratorReqUserIDType(object):
    pass


@attr.s
class CreateTaskCollaboratorReq(object):
    user_id_type: CreateTaskCollaboratorReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    task_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 任务 ID, 示例值："83912691-2e43-47fc-94a4-d512e03984fa"
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 任务协作者的 ID, 示例值："ou_99e1a581b36ecc4862cbfbce473f1234"


@attr.s
class CreateTaskCollaboratorRespCollaborator(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 任务协作者的 ID


@attr.s
class CreateTaskCollaboratorResp(object):
    collaborator: CreateTaskCollaboratorRespCollaborator = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 返回创建成功后的任务协作者


def _gen_create_task_collaborator_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateTaskCollaboratorResp,
        scope="Task",
        api="CreateTaskCollaborator",
        method="POST",
        url="https://open.feishu.cn/open-apis/task/v1/tasks/:task_id/collaborators",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveRootFolderMetaReq(object):
    pass


@attr.s
class GetDriveRootFolderMetaResp(object):
    token: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的 token
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的 id
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的所有者 id


def _gen_get_drive_root_folder_meta_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveRootFolderMetaResp,
        scope="Drive",
        api="GetDriveRootFolderMeta",
        method="GET",
        url="https://open.feishu.cn/open-apis/drive/explorer/v2/root_folder/meta",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTagChildren(object):
    pass


@attr.s
class CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTag(object):
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 展示名称
    children: CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTagChildren = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 同上：选项列表，只适用于多层下拉列表（最多可以设置三级下拉列表）


@attr.s
class CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildren(object):
    tag: CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTag = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 选项ID


@attr.s
class CreateHelpdeskTicketCustomizedFieldReqDropdownOptions(object):
    children: CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildren = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 选项列表


@attr.s
class CreateHelpdeskTicketCustomizedFieldReq(object):
    helpdesk_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 服务台ID, 示例值："1542164574896126"
    key_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 键名, 示例值："test dropdown"
    display_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 名称, 示例值："test dropdown"
    position: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 字段在列表后台管理列表中的位置, 示例值："3"
    field_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 类型, 示例值："dropdown"
    description: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 描述, 示例值："下拉示例"
    visible: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否可见, 示例值：true
    editable: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否可以修改, 示例值：true
    required: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否必填, 示例值：false
    dropdown_options: CreateHelpdeskTicketCustomizedFieldReqDropdownOptions = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 下拉列表选项
    dropdown_allow_multiple: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否支持多选，仅在字段类型是dropdown的时候有效, 示例值：true


@attr.s
class CreateHelpdeskTicketCustomizedFieldResp(object):
    pass


def _gen_create_helpdesk_ticket_customized_field_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateHelpdeskTicketCustomizedFieldResp,
        scope="Helpdesk",
        api="CreateHelpdeskTicketCustomizedField",
        method="POST",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/ticket_customized_fields",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteDriveSheetFileReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见 [概述](https://open.feishu.cn/document/ukTMukTMukTM/uUDN04SN0QjL1QDN/files/guide/introduction)


@attr.s
class DeleteDriveSheetFileResp(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheet 的 id 「字符串类型」
    result: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 删除结果


def _gen_delete_drive_sheet_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteDriveSheetFileResp,
        scope="Drive",
        api="DeleteDriveSheetFile",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/drive/explorer/v2/file/spreadsheets/:spreadsheetToken",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskCategoryReq(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 知识库分类ID, 示例值："6948728206392295444"


@attr.s
class GetHelpdeskCategoryResp(object):
    category_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 知识库分类ID
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 知识库分类ID，（旧版，请使用category_id）
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    helpdesk_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 服务台ID
    language: str = attr.ib(default="", metadata={"req_type": "json"})  # 语言


def _gen_get_helpdesk_category_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskCategoryResp,
        scope="Helpdesk",
        api="GetHelpdeskCategory",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/categories/:id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveFolderMetaReq(object):
    folder_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文件夹 token，用于在此文件夹下新建文档，获取方式见[概述](https://open.feishu.cn/document/ukTMukTMukTM/uUDN04SN0QjL1QDN/files/guide/introduction)


@attr.s
class GetDriveFolderMetaResp(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的 id
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的标题
    token: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的 token
    create_uid: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的创建者 id
    edit_uid: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的最后编辑者 id
    parent_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的上级目录 id
    own_uid: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件夹为个人文件夹时，为文件夹的所有者 id；文件夹为共享文件夹时，为文件夹树id


def _gen_get_drive_folder_meta_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveFolderMetaResp,
        scope="Drive",
        api="GetDriveFolderMeta",
        method="GET",
        url="https://open.feishu.cn/open-apis/drive/explorer/v2/folder/:folderToken/meta",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_file_upload_image import (
    UploadImageReq,
    UploadImageResp,
    _gen_upload_image_req,
)
from pylark.api_service_file_download_image import (
    DownloadImageReq,
    DownloadImageResp,
    _gen_download_image_req,
)
from pylark.api_service_file_upload_file import (
    UploadFileReq,
    UploadFileResp,
    _gen_upload_file_req,
)
from pylark.api_service_file_download_file import (
    DownloadFileReq,
    DownloadFileResp,
    _gen_download_file_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkFileService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def upload_image(
        self, request: UploadImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[UploadImageResp, Response]:
        return self.cli.raw_request(_gen_upload_image_req(request, options))

    def download_image(
        self, request: DownloadImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[DownloadImageResp, Response]:
        return self.cli.raw_request(_gen_download_image_req(request, options))

    def upload_file(
        self, request: UploadFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[UploadFileResp, Response]:
        return self.cli.raw_request(_gen_upload_file_req(request, options))

    def download_file(
        self, request: DownloadFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[DownloadFileResp, Response]:
        return self.cli.raw_request(_gen_download_file_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteBitableRecordReq(object):
    app_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # bitable app token, 示例值："appbcbWCzen6D8dezhoCH2RpMAh"
    table_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # table id, 示例值："tblsRc9GRRXKqhvW"
    record_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 单条记录的Id, 示例值："recpCsf4ME"


@attr.s
class DeleteBitableRecordResp(object):
    deleted: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否成功删除
    record_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 删除的记录 ID


def _gen_delete_bitable_record_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteBitableRecordResp,
        scope="Bitable",
        api="DeleteBitableRecord",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/bitable/v1/apps/:app_token/tables/:table_id/records/:record_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskCategoryListReq(object):
    lang: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 知识库分类语言, 示例值："zh_cn"
    order_by: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 排序键。1: 根据知识库分类更新时间排序, 示例值：1
    asc: bool = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 顺序。true: 正序；false：反序, 示例值：true


@attr.s
class GetHelpdeskCategoryListRespCategorieChildren(object):
    pass


@attr.s
class GetHelpdeskCategoryListRespCategorie(object):
    category_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 知识库分类ID
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 知识库分类ID，（旧版，请使用category_id）
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    parent_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 父知识库分类ID
    helpdesk_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 服务台ID
    language: str = attr.ib(default="", metadata={"req_type": "json"})  # 语言
    children: typing.List[GetHelpdeskCategoryListRespCategorieChildren] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 子分类详情


@attr.s
class GetHelpdeskCategoryListResp(object):
    categories: typing.List[GetHelpdeskCategoryListRespCategorie] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 知识库分类列表


def _gen_get_helpdesk_category_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskCategoryListResp,
        scope="Helpdesk",
        api="GetHelpdeskCategoryList",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/categories",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DownloadFileReq(object):
    file_key: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文件的key, 示例值："file_456a92d6-c6ea-4de4-ac3f-7afcf44ac78g"


@attr.s
class DownloadFileRespFile(object):
    pass


@attr.s
class DownloadFileResp(object):
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )


@attr.s
class DownloadFileResp(object):
    is_file: bool = attr.ib(factory=lambda: bool(), metadata={"req_type": "json"})
    code: int = attr.ib(default=0, metadata={"req_type": "json"})
    msg: str = attr.ib(default="", metadata={"req_type": "json"})
    data: DownloadFileResp = attr.ib(default=None, metadata={"req_type": "json"})


def _gen_download_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DownloadFileResp,
        scope="File",
        api="DownloadFile",
        method="GET",
        url="https://open.feishu.cn/open-apis/im/v1/files/:file_key",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



from pylark import TokenExpire
from pylark.lark_request import RawRequestReq, _new_method_option, Request, Response
from typing import TYPE_CHECKING, Tuple
import attr

if TYPE_CHECKING:
    from pylark.lark import Lark


# https://open.feishu.cn/document/ukTMukTMukTM/ukDNz4SO0MjL5QzM/g



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireTalentReq(object):
    talent_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 人才ID, 示例值："6891560630172518670"


@attr.s
class GetHireTalentRespTalentInterviewRegistration(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    registration_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间


@attr.s
class GetHireTalentRespTalentResumeSource(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名


@attr.s
class GetHireTalentRespTalentSns(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    sns_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # SNS类型, 可选值有: `1`：领英, `2`：脉脉, `3`：微信, `4`：微博, `5`：Github, `6`：知乎, `7`：脸书, `8`：推特, `9`：Whatsapp, `10`：个人网站, `11`：QQ
    link: str = attr.ib(default="", metadata={"req_type": "json"})  # SNS链接


@attr.s
class GetHireTalentRespTalentLanguage(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    language: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 语言, 可选值有: `1`：英语, `2`：法语, `3`：日语, `4`：韩语, `5`：德语, `6`：俄语, `7`：西班牙语, `8`：葡萄牙语, `9`：阿拉伯语, `10`：印地语, `11`：印度斯坦语, `12`：孟加拉语, `13`：豪萨语, `14`：旁遮普语, `15`：波斯语, `16`：斯瓦西里语, `17`：泰卢固语, `18`：土耳其语, `19`：意大利语, `20`：爪哇语, `21`：泰米尔语, `22`：马拉地语, `23`：越南语, `24`：普通话, `25`：粤语
    proficiency: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 熟练程度, 可选值有: `1`：入门, `2`：日常会话, `3`：商务会话, `4`：无障碍沟通, `5`：母语


@attr.s
class GetHireTalentRespTalentCertificate(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 证件名称
    desc: str = attr.ib(default="", metadata={"req_type": "json"})  # 证件描述


@attr.s
class GetHireTalentRespTalentCompetition(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 竞赛名称
    desc: str = attr.ib(default="", metadata={"req_type": "json"})  # 竞赛描述


@attr.s
class GetHireTalentRespTalentAward(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    award_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 获奖时间
    desc: str = attr.ib(default="", metadata={"req_type": "json"})  # 描述


@attr.s
class GetHireTalentRespTalentWorks(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    link: str = attr.ib(default="", metadata={"req_type": "json"})  # 链接
    desc: str = attr.ib(default="", metadata={"req_type": "json"})  # 描述
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名字


@attr.s
class GetHireTalentRespTalentProject(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 项目名称
    role: str = attr.ib(default="", metadata={"req_type": "json"})  # 项目角色
    link: str = attr.ib(default="", metadata={"req_type": "json"})  # 项目链接
    desc: str = attr.ib(default="", metadata={"req_type": "json"})  # 描述
    start_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 开始时间
    end_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 结束时间


@attr.s
class GetHireTalentRespTalentCareer(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    company: str = attr.ib(default="", metadata={"req_type": "json"})  # 公司
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位
    desc: str = attr.ib(default="", metadata={"req_type": "json"})  # 描述
    start_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 开始时间
    end_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 结束时间
    tag_list: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 标签, 可选值有: `1`：985学校, `2`：211学校, `3`：一本, `4`：国外院校QS200, `5`：百度 阿里 腾讯, `6`：头条, 美团, 滴滴, `7`：其它大厂, `8`：猎头渠道, `9`：内推渠道, `10`：互联网大厂（包含 BAT/TMD）, `11`：熟人内推, `100`：email, `101`：mobile, `102`：猎头保护中, `103`：已入职, `104`：已离职


@attr.s
class GetHireTalentRespTalentEducation(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    degree: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 学位, 可选值有: `1`：小学, `2`：初中, `3`：专职, `4`：高中, `5`：大专, `6`：本科, `7`：硕士, `8`：博士, `9`：其他
    school: str = attr.ib(default="", metadata={"req_type": "json"})  # 学校
    field_of_study: str = attr.ib(default="", metadata={"req_type": "json"})  # 专业
    start_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 开始时间
    end_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 结束时间
    education_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 学历类型, 可选值有: `1`：非中国大陆, `2`：统招全日制, `3`：非全日制, `4`：自考, `5`：其他
    academic_ranking: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 成绩排名, 可选值有: `5`：前 5 %, `10`：前 10 %, `20`：前 20 %, `30`：前 30 %, `50`：前 50 %, `-1`：其他
    tag_list: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 标记, 可选值有: `1`：985学校, `2`：211学校, `3`：一本, `4`：国外院校QS200, `5`：百度 阿里 腾讯, `6`：头条, 美团, 滴滴, `7`：其它大厂, `8`：猎头渠道, `9`：内推渠道, `10`：互联网大厂（包含 BAT/TMD）, `11`：熟人内推, `100`：email, `101`：mobile, `102`：猎头保护中, `103`：已入职, `104`：已离职


@attr.s
class GetHireTalentRespTalentBasicInfoPreferredCity(object):
    city_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 城市码
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名字
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名


@attr.s
class GetHireTalentRespTalentBasicInfoHometownCity(object):
    city_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 城市码
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名字
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名


@attr.s
class GetHireTalentRespTalentBasicInfoCurrentCity(object):
    city_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 城市码
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名字
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名


@attr.s
class GetHireTalentRespTalentBasicInfoNationality(object):
    nationality_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 国家编码
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名字
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名


@attr.s
class GetHireTalentRespTalentBasicInfo(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名字
    mobile: str = attr.ib(default="", metadata={"req_type": "json"})  # 手机
    mobile_country_code: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 手机国家代码
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 邮箱
    experience_years: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工作年限
    age: int = attr.ib(default=0, metadata={"req_type": "json"})  # 年龄
    nationality: GetHireTalentRespTalentBasicInfoNationality = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 国籍
    gender: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 性别, 可选值有: `1`：男, `2`：女, `3`：其他
    current_city: GetHireTalentRespTalentBasicInfoCurrentCity = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 当前所在城市信息
    hometown_city: GetHireTalentRespTalentBasicInfoHometownCity = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 家乡
    preferred_city_list: typing.List[
        GetHireTalentRespTalentBasicInfoPreferredCity
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 偏好城市
    identification_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 证件类型, 可选值有: `1`：中国 - 居民身份证, `2`：护照, `3`：中国 - 港澳居民居住证, `4`：中国 - 台湾居民来往大陆通行证, `5`：其他, `6`：中国 - 港澳居民来往内地通行证, `9`：中国 - 台湾居民居住证
    identification_number: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 证件号
    birthday: int = attr.ib(default=0, metadata={"req_type": "json"})  # 生日


@attr.s
class GetHireTalentRespTalent(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    basic_info: GetHireTalentRespTalentBasicInfo = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 基础信息
    education_list: typing.List[GetHireTalentRespTalentEducation] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 教育经历
    career_list: typing.List[GetHireTalentRespTalentCareer] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 工作经历
    project_list: typing.List[GetHireTalentRespTalentProject] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 项目经历
    works_list: typing.List[GetHireTalentRespTalentWorks] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 作品集
    award_list: typing.List[GetHireTalentRespTalentAward] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 获奖列表
    competition_list: typing.List[GetHireTalentRespTalentCompetition] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 竞赛列表
    certificate_list: typing.List[GetHireTalentRespTalentCertificate] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 证书列表
    language_list: typing.List[GetHireTalentRespTalentLanguage] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 语言列表
    sns_list: typing.List[GetHireTalentRespTalentSns] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # SNS列表
    resume_source_list: typing.List[GetHireTalentRespTalentResumeSource] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 简历来源
    interview_registration_list: typing.List[
        GetHireTalentRespTalentInterviewRegistration
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 面试登记表
    resume_attachment_id_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 简历附件id列表（按照简历创建时间降序）


@attr.s
class GetHireTalentResp(object):
    talent: GetHireTalentRespTalent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 人才信息


def _gen_get_hire_talent_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireTalentResp,
        scope="Hire",
        api="GetHireTalent",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/talents/:talent_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetMeetingRoomBuildingReq(object):
    building_ids: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用于查询指定建筑物的 ID
    fields: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用于指定返回的字段名，每个字段名之间用逗号 "," 分隔，如：“id,name”，"*" 表示返回全部字段，可选字段有："id,name,description,floors"，默认返回所有字段


@attr.s
class BatchGetMeetingRoomBuildingRespBuilding(object):
    building_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 建筑物 ID
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 建筑物的相关描述
    floors: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 属于当前建筑物的所有楼层列表
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 建筑物名称


@attr.s
class BatchGetMeetingRoomBuildingResp(object):
    buildings: BatchGetMeetingRoomBuildingRespBuilding = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 建筑列表


def _gen_batch_get_meeting_room_building_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetMeetingRoomBuildingResp,
        scope="MeetingRoom",
        api="BatchGetMeetingRoomBuilding",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/building/batch_get",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_search_data_source_item_create import (
    CreateSearchDataSourceItemReq,
    CreateSearchDataSourceItemResp,
    _gen_create_search_data_source_item_req,
)
from pylark.api_service_search_data_source_item_get import (
    GetSearchDataSourceItemReq,
    GetSearchDataSourceItemResp,
    _gen_get_search_data_source_item_req,
)
from pylark.api_service_search_data_source_item_delete import (
    DeleteSearchDataSourceItemReq,
    DeleteSearchDataSourceItemResp,
    _gen_delete_search_data_source_item_req,
)
from pylark.api_service_search_data_source_create import (
    CreateSearchDataSourceReq,
    CreateSearchDataSourceResp,
    _gen_create_search_data_source_req,
)
from pylark.api_service_search_data_source_get import (
    GetSearchDataSourceReq,
    GetSearchDataSourceResp,
    _gen_get_search_data_source_req,
)
from pylark.api_service_search_data_source_patch import (
    UpdateSearchDataSourceReq,
    UpdateSearchDataSourceResp,
    _gen_update_search_data_source_req,
)
from pylark.api_service_search_data_source_list import (
    GetSearchDataSourceListReq,
    GetSearchDataSourceListResp,
    _gen_get_search_data_source_list_req,
)
from pylark.api_service_search_data_source_delete import (
    DeleteSearchDataSourceReq,
    DeleteSearchDataSourceResp,
    _gen_delete_search_data_source_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkSearchService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def create_search_data_source_item(
        self, request: CreateSearchDataSourceItemReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateSearchDataSourceItemResp, Response]:
        return self.cli.raw_request(
            _gen_create_search_data_source_item_req(request, options)
        )

    def get_search_data_source_item(
        self, request: GetSearchDataSourceItemReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetSearchDataSourceItemResp, Response]:
        return self.cli.raw_request(
            _gen_get_search_data_source_item_req(request, options)
        )

    def delete_search_data_source_item(
        self, request: DeleteSearchDataSourceItemReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteSearchDataSourceItemResp, Response]:
        return self.cli.raw_request(
            _gen_delete_search_data_source_item_req(request, options)
        )

    def create_search_data_source(
        self, request: CreateSearchDataSourceReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateSearchDataSourceResp, Response]:
        return self.cli.raw_request(
            _gen_create_search_data_source_req(request, options)
        )

    def get_search_data_source(
        self, request: GetSearchDataSourceReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetSearchDataSourceResp, Response]:
        return self.cli.raw_request(_gen_get_search_data_source_req(request, options))

    def update_search_data_source(
        self, request: UpdateSearchDataSourceReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateSearchDataSourceResp, Response]:
        return self.cli.raw_request(
            _gen_update_search_data_source_req(request, options)
        )

    def get_search_data_source_list(
        self, request: GetSearchDataSourceListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetSearchDataSourceListResp, Response]:
        return self.cli.raw_request(
            _gen_get_search_data_source_list_req(request, options)
        )

    def delete_search_data_source(
        self, request: DeleteSearchDataSourceReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteSearchDataSourceResp, Response]:
        return self.cli.raw_request(
            _gen_delete_search_data_source_req(request, options)
        )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateDriveImportTaskReqPoint(object):
    mount_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 挂载类型, 示例值：1, 可选值有: `1`：挂载到云空间
    mount_key: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 挂载位置,对于mount_type=1, 云空间目录token，空表示根目录, 示例值：""fldxxxxxxxx""


@attr.s
class CreateDriveImportTaskReq(object):
    file_extension: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 导入文件格式后缀, 示例值："xlsx"
    file_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 导入文件Drive FileToken, 示例值："boxcnxe5OxxxxxxxSNdsJviENsk"
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 导入目标云文档格式, 示例值："sheet"
    file_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 导入目标云文档文件名 ，若为空使用Drive文件名, 示例值："test"
    point: CreateDriveImportTaskReqPoint = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 挂载点


@attr.s
class CreateDriveImportTaskResp(object):
    ticket: str = attr.ib(default="", metadata={"req_type": "json"})  # 导入任务ID


def _gen_create_drive_import_task_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateDriveImportTaskResp,
        scope="Drive",
        api="CreateDriveImportTask",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/v1/import_tasks",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetSearchDataSourceItemReq(object):
    data_source_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 数据源的id, 示例值："service_ticket"
    item_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 数据记录的唯一标识, 示例值："01010111"


@attr.s
class GetSearchDataSourceItemRespItemContent(object):
    format: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 内容的格式, 可选值有: `html`：html格式, `plaintext`：纯文本格式
    content_data: str = attr.ib(default="", metadata={"req_type": "json"})  # 全文数据


@attr.s
class GetSearchDataSourceItemRespItemMetadata(object):
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 该条数据记录对应的标题
    source_url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 该条数据记录对应的跳转url
    create_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 数据项的创建时间。Unix 时间，单位为秒
    update_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 数据项的更新时间。Unix 时间，单位为秒


@attr.s
class GetSearchDataSourceItemRespItemACL(object):
    access: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 权限类型，优先级：Deny > Allow。默认为全员不可见，即 deny。, 可选值有: `allow`：允许访问, `deny`：禁止访问
    value: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 设置的权限值，例如 userID 、groupID，依赖 type 描述。,**注**：在 type 为 user 且 access 为 allow 时，可填 "everyone" 来表示该数据项对全员可见。
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 权限值类型, 可选值有: `user`：访问权限控制中指定用户可以访问或拒绝访问该条数据, `group`：访问权限控制中指定用户组可以访问或拒绝访问该条数据


@attr.s
class GetSearchDataSourceItemRespItem(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # item 在 datasource 中的唯一标识
    acl: GetSearchDataSourceItemRespItemACL = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # item 的访问权限控制
    metadata: GetSearchDataSourceItemRespItemMetadata = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # item 的元信息
    structured_data: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结构化数据（以 json 字符串传递），这些字段是搜索结果的展示字段（title字段无须在此另外指定）；目前支持的key为：, summary：搜索结果的摘要；, icon_url：搜索结果的icon地址；, footer：搜索结果的脚注
    content: GetSearchDataSourceItemRespItemContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 非结构化数据，如文档文本，飞书搜索会用来做召回


@attr.s
class GetSearchDataSourceItemResp(object):
    item: GetSearchDataSourceItemRespItem = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 数据项实例


def _gen_get_search_data_source_item_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetSearchDataSourceItemResp,
        scope="Search",
        api="GetSearchDataSourceItem",
        method="GET",
        url="https://open.feishu.cn/open-apis/search/v2/data_sources/:data_source_id/items/:item_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class SubscribeCalendarChangeEventReq(object):
    pass


@attr.s
class SubscribeCalendarChangeEventResp(object):
    pass


def _gen_subscribe_calendar_change_event_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=SubscribeCalendarChangeEventResp,
        scope="Calendar",
        api="SubscribeCalendarChangeEvent",
        method="POST",
        url="https://open.feishu.cn/open-apis/calendar/v4/calendars/subscription",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class QuerySheetFilterViewReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 表格 token, 示例值："shtcnmBA*****yGehy8"
    sheet_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 子表 id, 示例值："0b**12"


@attr.s
class QuerySheetFilterViewRespItem(object):
    filter_view_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 筛选视图 id
    filter_view_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 筛选视图名字
    range_: str = attr.ib(default="", metadata={"req_type": "json"})  # 筛选视图的筛选范围


@attr.s
class QuerySheetFilterViewResp(object):
    items: typing.List[QuerySheetFilterViewRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 子表的所有筛选视图信息，id、name、range


def _gen_query_sheet_filter_view_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=QuerySheetFilterViewResp,
        scope="Drive",
        api="QuerySheetFilterView",
        method="GET",
        url="https://open.feishu.cn/open-apis/sheets/v3/spreadsheets/:spreadsheet_token/sheets/:sheet_id/filter_views/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateDriveDocReq(object):
    folder_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件夹 token，获取方式见[准备接入文档 API](https://open.feishu.cn/document/ukTMukTMukTM/ugzNzUjL4czM14CO3MTN/guide/getting-start)；空表示根目录
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 传入符合[文档数据结构](https://open.feishu.cn/document/ukTMukTMukTM/uAzM5YjLwMTO24CMzkjN)的字符串，若为空表示创建空文档


@attr.s
class CreateDriveDocResp(object):
    obj_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 新建文档的token
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 新建文档的访问链接


def _gen_create_drive_doc_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateDriveDocResp,
        scope="Drive",
        api="CreateDriveDoc",
        method="POST",
        url="https://open.feishu.cn/open-apis/doc/v2/create",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAttendanceStatisticsHeaderReqEmployeeType(object):
    pass


@attr.s
class GetAttendanceStatisticsHeaderReq(object):
    employee_type: GetAttendanceStatisticsHeaderReqEmployeeType = attr.ib(
        factory=lambda: GetAttendanceStatisticsHeaderReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 用户 ID 类型, 可选值有: `employee_id`, `employee_no`
    locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 语言类型, 可选值有: `en`：英文, `ja`：日文, `zh`：中文
    stats_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 统计类型,      , **可选值有**：     , `daily`：日度统计, `month`：月度统计
    start_date: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 开始时间, 示例值：20210316,      ,      （时间间隔不超过 40 天）
    end_date: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 结束时间, 示例值：20210323


@attr.s
class GetAttendanceStatisticsHeaderRespUserStatsFieldFieldChildField(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 字段编号
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 字段名称
    time_unit: str = attr.ib(default="", metadata={"req_type": "json"})  # 时间类型


@attr.s
class GetAttendanceStatisticsHeaderRespUserStatsFieldField(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 字段编号
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 字段标题
    child_fields: typing.List[
        GetAttendanceStatisticsHeaderRespUserStatsFieldFieldChildField
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 子字段列表


@attr.s
class GetAttendanceStatisticsHeaderRespUserStatsField(object):
    stats_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 统计类型,    , 可选值有: `daily`：日度统计, `month`：月度统计
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 ID
    fields: typing.List[GetAttendanceStatisticsHeaderRespUserStatsFieldField] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 字段列表


@attr.s
class GetAttendanceStatisticsHeaderResp(object):
    user_stats_field: GetAttendanceStatisticsHeaderRespUserStatsField = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 统计数据表头


def _gen_get_attendance_statistics_header_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAttendanceStatisticsHeaderResp,
        scope="Attendance",
        api="GetAttendanceStatisticsHeader",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_stats_fields/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UploadImageReqImage(object):
    pass


@attr.s
class UploadImageReqImageType(object):
    pass


@attr.s
class UploadImageReq(object):
    image_type: UploadImageReqImageType = attr.ib(
        factory=lambda: UploadImageReqImageType(), metadata={"req_type": "json"}
    )  # 图片类型, 示例值："message", 可选值有: `message`：用于发送消息, `avatar`：用于设置头像
    image: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 图片内容, 示例值：二进流


@attr.s
class UploadImageResp(object):
    image_key: str = attr.ib(default="", metadata={"req_type": "json"})  # 图片的key


def _gen_upload_image_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UploadImageResp,
        scope="File",
        api="UploadImage",
        method="POST",
        url="https://open.feishu.cn/open-apis/im/v1/images",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        is_file=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetMeetingRoomCountryListReq(object):
    pass


@attr.s
class GetMeetingRoomCountryListRespCountries(object):
    country_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 国家地区ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 国家地区名称


@attr.s
class GetMeetingRoomCountryListResp(object):
    countries: GetMeetingRoomCountryListRespCountries = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 国家地区列表


def _gen_get_meeting_room_country_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetMeetingRoomCountryListResp,
        scope="MeetingRoom",
        api="GetMeetingRoomCountryList",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/country/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteHelpdeskAgentSkillReq(object):
    agent_skill_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # agent group id, 示例值："test-skill-id"


@attr.s
class DeleteHelpdeskAgentSkillResp(object):
    pass


def _gen_delete_helpdesk_agent_skill_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteHelpdeskAgentSkillResp,
        scope="Helpdesk",
        api="DeleteHelpdeskAgentSkill",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/agent_skills/:agent_skill_id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetMeetingRoomSummaryReqEventUid(object):
    uid: str = attr.ib(default="", metadata={"req_type": "json"})  # 日程的唯一id
    original_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 日程实例原始时间，非重复日程必为0。重复日程若为0则表示回复其所有实例，否则表示回复单个实例。


@attr.s
class BatchGetMeetingRoomSummaryReq(object):
    event_uids: BatchGetMeetingRoomSummaryReqEventUid = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 需要查询的日程Uid和Original time


@attr.s
class BatchGetMeetingRoomSummaryRespErrorEventUid(object):
    uid: str = attr.ib(default="", metadata={"req_type": "json"})  # 日程的唯一id
    original_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 日程实例原始时间，非重复日程必为0。重复日程若为0则表示回复其所有实例，否则表示回复单个实例。
    error_msg: str = attr.ib(default="", metadata={"req_type": "json"})  # 错误信息


@attr.s
class BatchGetMeetingRoomSummaryRespEventInfo(object):
    uid: str = attr.ib(default="", metadata={"req_type": "json"})  # 日程的唯一id
    original_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 日程实例原始时间，非重复日程必为0。重复日程若为0则表示回复其所有实例，否则表示回复单个实例。
    summary: str = attr.ib(default="", metadata={"req_type": "json"})  # 日程主题


@attr.s
class BatchGetMeetingRoomSummaryResp(object):
    event_infos: BatchGetMeetingRoomSummaryRespEventInfo = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 成功查询到的日程信息
    error_event_uids: BatchGetMeetingRoomSummaryRespErrorEventUid = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 没有查询到的日程


def _gen_batch_get_meeting_room_summary_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetMeetingRoomSummaryResp,
        scope="MeetingRoom",
        api="BatchGetMeetingRoomSummary",
        method="POST",
        url="https://open.feishu.cn/open-apis/meeting_room/summary/batch_get",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApplicationUserAdminScopeReq(object):
    employee_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 支持通过 open_id 或者 employee_id 查询，不支持混合两种 ID 进行查询，其中 employee_id 同通讯录 v3 版本中的 user_id
    open_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 支持通过 open_id 或者 employee_id 查询，不支持混合两种 ID 进行查询，其中 employee_id 同通讯录 v3 版本中的 user_id


@attr.s
class GetApplicationUserAdminScopeResp(object):
    is_all: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否管理所有部门
    department_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 管理的部门列表，当 is_all 为 true 时，不返回该字段


def _gen_get_application_user_admin_scope_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApplicationUserAdminScopeResp,
        scope="Application",
        api="GetApplicationUserAdminScope",
        method="GET",
        url="https://open.feishu.cn/open-apis/contact/v1/user/admin_scope/get",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetUserInfoReq(object):
    pass


@attr.s
class GetUserInfoResp(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户姓名
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户英文名称
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像
    avatar_thumb: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像 72x72
    avatar_middle: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户头像 240x240
    avatar_big: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像 640x640
    email: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户邮箱，拥有"获取用户邮箱"权限时返回
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户的 user_id，申请了"获取用户user_id"权限的应用返回该字段
    mobile: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户手机号，申请了"获取用户手机号"权限的应用返回该字段
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户在应用内的唯一标识
    union_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户对ISV的唯一标识，对于同一个ISV，用户在其名下所有应用的union_id相同
    tenant_key: str = attr.ib(default="", metadata={"req_type": "json"})  # 用于企业标识


def _gen_get_user_info_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetUserInfoResp,
        scope="Auth",
        api="GetUserInfo",
        method="GET",
        url="https://open.feishu.cn/open-apis/authen/v1/user_info",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAdminDeptStatsReqDepartmentIDType(object):
    pass


@attr.s
class GetAdminDeptStatsReq(object):
    department_id_type: GetAdminDeptStatsReqDepartmentIDType = attr.ib(
        factory=lambda: GetAdminDeptStatsReqDepartmentIDType(),
        metadata={"req_type": "query"},
    )  # 部门ID类型, 示例值："open_department_id", 可选值有: `department_id`：部门的 ID, `open_department_id`：部门的 Open ID
    start_date: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 起始日期（包含），格式是YYYY-mm-dd, 示例值："2020-02-15"
    end_date: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 终止日期（包含），格式是YYYY-mm-dd，起止日期之间相差不能超过91天（包含91天）, 示例值："2020-02-15"
    department_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 部门的 ID，取决于department_id_type，仅支持根部门及其下前4级子部门, 示例值："od-382e2793cfc9471f892e8a672987654c"
    contains_child_dept: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "query"}
    )  # 是否包含子部门，如果该值为false，则只查出本部门直属用户活跃和功能使用数据；如果该值为true，则查出该部门以及其子部门（子部门层级最多不超过根部门下的前4级）的用户活跃和功能使用数据, 示例值：false
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小，默认是10, 示例值：10, 取值范围：`1` ～ `20`
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；当返回的has_more为true时，会返回新的page_token，再次调用接口，传入这个page_token，将获得下一页数据, 示例值："2"


@attr.s
class GetAdminDeptStatsRespItem(object):
    date: str = attr.ib(default="", metadata={"req_type": "json"})  # 日期
    department_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 部门的department_id 或者open_department_id
    department_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门名字
    department_path: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门路径
    total_user_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 部门总人数
    active_user_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 激活人数
    active_user_rate: str = attr.ib(default="", metadata={"req_type": "json"})  # 激活率
    suite_dau: int = attr.ib(default=0, metadata={"req_type": "json"})  # 活跃人数
    suite_active_rate: str = attr.ib(default="", metadata={"req_type": "json"})  # 活跃率
    new_user_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 新用户数
    new_active_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 新激活数
    resign_user_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 离职人数
    im_dau: int = attr.ib(default=0, metadata={"req_type": "json"})  # 消息活跃人数
    send_messenger_user_num: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 发送消息人数
    send_messenger_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 发送消息数
    avg_send_messenger_num: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 人均发送消息数
    docs_dau: int = attr.ib(default=0, metadata={"req_type": "json"})  # 云文档活跃人数
    create_docs_user_num: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 创建文件人数
    create_docs_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建文件数
    avg_create_docs_num: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 人均创建文件数
    cal_dau: int = attr.ib(default=0, metadata={"req_type": "json"})  # 日历活跃人数
    create_cal_user_num: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 创建日程人数
    create_cal_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建日程数
    avg_create_cal_num: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 人均创建日程数
    vc_dau: int = attr.ib(default=0, metadata={"req_type": "json"})  # 音视频会议活跃人数
    vc_duration: int = attr.ib(default=0, metadata={"req_type": "json"})  # 会议时长（分钟）
    avg_vc_duration: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 人均会议时长（分钟）


@attr.s
class GetAdminDeptStatsResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 分页查询时返回，代表是否还有更多数据
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，下一页分页的token
    items: typing.List[GetAdminDeptStatsRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 数据报表


def _gen_get_admin_dept_stats_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAdminDeptStatsResp,
        scope="Admin",
        api="GetAdminDeptStats",
        method="GET",
        url="https://open.feishu.cn/open-apis/admin/v1/admin_dept_stats",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UploadFaceVerifyImageReqImage(object):
    pass


@attr.s
class UploadFaceVerifyImageReq(object):
    open_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用户应用标识, 与employee_id二选其一
    employee_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用户租户标识, 与open_id二选其一
    image: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 带有头像的人脸照片


@attr.s
class UploadFaceVerifyImageResp(object):
    face_uid: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 人脸图片用户Uid，需返回给应用小程序，作为小程序调起人脸识别接口的uid参数


def _gen_upload_face_verify_image_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UploadFaceVerifyImageResp,
        scope="HumanAuth",
        api="UploadFaceVerifyImage",
        method="POST",
        url="https://open.feishu.cn/open-apis/face_verify/v1/upload_face_image",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        is_file=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UploadAttendanceFileReqFile(object):
    pass


@attr.s
class UploadAttendanceFileReq(object):
    file_name: str = attr.ib(default="", metadata={"req_type": "query"})  # 文件名
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文件


@attr.s
class UploadAttendanceFileRespFile(object):
    file_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件 ID


@attr.s
class UploadAttendanceFileResp(object):
    file: UploadAttendanceFileRespFile = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文件


def _gen_upload_attendance_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UploadAttendanceFileResp,
        scope="Attendance",
        api="UploadAttendanceFile",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/files/upload",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        is_file=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateAttendanceUserSettingsReqUserSetting(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 ID
    face_key: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 人脸照片 key（通过文件上传接口得到）


@attr.s
class UpdateAttendanceUserSettingsReqEmployeeType(object):
    pass


@attr.s
class UpdateAttendanceUserSettingsReq(object):
    employee_type: UpdateAttendanceUserSettingsReqEmployeeType = attr.ib(
        factory=lambda: UpdateAttendanceUserSettingsReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 用户类型,      , 可选值有: `employee_id`： 员工 ID, `employee_no`： 员工工号
    user_setting: UpdateAttendanceUserSettingsReqUserSetting = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 用户信息


@attr.s
class UpdateAttendanceUserSettingsRespUserSetting(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 ID
    face_key: str = attr.ib(default="", metadata={"req_type": "json"})  # 人脸照片 key


@attr.s
class UpdateAttendanceUserSettingsResp(object):
    user_setting: UpdateAttendanceUserSettingsRespUserSetting = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 用户设置


def _gen_update_attendance_user_settings_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateAttendanceUserSettingsResp,
        scope="Attendance",
        api="UpdateAttendanceUserSettings",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_settings/modify",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteCalendarTimeoffEventReq(object):
    timeoff_event_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 休假申请的唯一标识id, 示例值："timeoff:XXXXXX-XXXX-0917-1623-aa493d591a39"


@attr.s
class DeleteCalendarTimeoffEventResp(object):
    pass


def _gen_delete_calendar_timeoff_event_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteCalendarTimeoffEventResp,
        scope="Calendar",
        api="DeleteCalendarTimeoffEvent",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/calendar/v4/timeoff_events/:timeoff_event_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UploadApprovalFileReqContent(object):
    pass


@attr.s
class UploadApprovalFileReq(object):
    name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件名（需包含文件扩展名，如“文件.doc”
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件类型（image 或 attachment）
    content: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文件


@attr.s
class UploadApprovalFileResp(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件标识码（用于创建审批实例）
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件 url


def _gen_upload_approval_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UploadApprovalFileResp,
        scope="Approval",
        api="UploadApprovalFile",
        method="POST",
        url="https://www.feishu.cn/approval/openapi/v2/file/upload",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        is_file=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class PrependSheetValueReqValueRangeValues(object):
    pass


@attr.s
class PrependSheetValueReqValueRange(object):
    range_: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # ⁣查询范围，包含 sheetId 与单元格范围两部分，目前支持四种索引方式，详见 [在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    values: typing.List[typing.List[PrependSheetValueReqValueRangeValues]] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 需要写入的值，如要写入公式、超链接、email、@人等，可详看附录[sheet 支持写入数据类型](https://open.feishu.cn/document/ukTMukTMukTM/ugjN1UjL4YTN14CO2UTN)


@attr.s
class PrependSheetValueReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # sheet的token，获取方式见 [在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    value_range: PrependSheetValueReqValueRange = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 值与范围


@attr.s
class PrependSheetValueRespUpdates(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet 的 token
    updated_range: str = attr.ib(default="", metadata={"req_type": "json"})  # 写入的范围
    updated_rows: int = attr.ib(default=0, metadata={"req_type": "json"})  # 写入的行数
    updated_columns: int = attr.ib(default=0, metadata={"req_type": "json"})  # 写入的列数
    updated_cells: int = attr.ib(default=0, metadata={"req_type": "json"})  # 写入的单元格总数
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # sheet 的版本号


@attr.s
class PrependSheetValueResp(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet 的 token
    table_range: str = attr.ib(default="", metadata={"req_type": "json"})  # 写入的范围
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # sheet 的版本号
    updates: PrependSheetValueRespUpdates = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 插入数据的范围、行列数等


def _gen_prepend_sheet_value_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=PrependSheetValueResp,
        scope="Drive",
        api="PrependSheetValue",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/values_prepend",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenMiniProgramReq(object):
    app_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 小程序 appId(可从「开发者后台-凭证与基础信息」获取)
    mode: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # PC小程序启动模式，枚举值包括：<br>`sidebar-semi`：聊天的侧边栏打开<br>`appCenter`：工作台中打开<br>`window`：独立大窗口打开<br>`window-semi`：独立小窗口打开，3.33版本开始支持此模式
    path: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 需要跳转的页面路径，路径后可以带参数。也可以使用 path_android、path_ios、path_pc 参数对不同的客户端指定不同的path
    path_android: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 同 path 参数，Android 端会优先使用该参数，如果该参数不存在，则会使用 path 参数
    path_ios: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 同 path 参数，iOS 端会优先使用该参数，如果该参数不存在，则会使用 path 参数
    path_pc: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 同 path 参数，PC 端会优先使用该参数，如果该参数不存在，则会使用 path 参数
    bdp_launch_query: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自定义启动参数。可通过 [getHostLaunchQuery](https://open.feishu.cn/document/uYjL24iN/ugzM4UjL4MDO14COzgTN) 接口取得
    min_lk_ver: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 指定 AppLink 协议能够兼容的最小飞书版本，使用三位版本号 x.y.z。如果当前飞书版本号小于min_lk_ver，打开该 AppLink 会显示为兼容页面


@attr.s
class OpenMiniProgramResp(object):
    pass


def _gen_open_mini_program_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenMiniProgramResp,
        scope="AppLink",
        api="OpenMiniProgram",
        method="",
        url="https://applink.feishu.cn/client/mini_program/open",
        body=request,
        method_option=_new_method_option(options),
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteSearchDataSourceReq(object):
    data_source_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 数据源的唯一标识, 示例值："6953903108179099667"


@attr.s
class DeleteSearchDataSourceResp(object):
    pass


def _gen_delete_search_data_source_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteSearchDataSourceResp,
        scope="Search",
        api="DeleteSearchDataSource",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/search/v2/data_sources/:data_source_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetPublicMailboxMemberReqUserIDType(object):
    pass


@attr.s
class GetPublicMailboxMemberReq(object):
    user_id_type: GetPublicMailboxMemberReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    public_mailbox_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 公共邮箱唯一标识或公共邮箱地址, 示例值："xxxxxxxxxxxxxxx 或 test_public_mailbox@xxx.xx"
    member_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 公共邮箱内成员唯一标识, 示例值："xxxxxxxxxxxxxxx"


@attr.s
class GetPublicMailboxMemberRespType(object):
    pass


@attr.s
class GetPublicMailboxMemberResp(object):
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 公共邮箱内成员唯一标识
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户内用户的唯一标识（当成员类型是USER时有值）
    type: GetPublicMailboxMemberRespType = attr.ib(
        factory=lambda: GetPublicMailboxMemberRespType(), metadata={"req_type": "json"}
    )  # 成员类型, 可选值有: `USER`：内部用户


def _gen_get_public_mailbox_member_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetPublicMailboxMemberResp,
        scope="Mail",
        api="GetPublicMailboxMember",
        method="GET",
        url="https://open.feishu.cn/open-apis/mail/v1/public_mailboxes/:public_mailbox_id/members/:member_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireJobManagerReqUserIDType(object):
    pass


@attr.s
class GetHireJobManagerReq(object):
    user_id_type: GetHireJobManagerReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    job_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 职位ID, 示例值："1618209327096"
    manager_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 人员ID，目前传职位ID, 示例值："1618209327096"


@attr.s
class GetHireJobManagerRespInfo(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位ID
    recruiter_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 招聘负责人ID
    hiring_manager_id_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 用人经理ID列表
    assistant_id_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 协助人ID列表


@attr.s
class GetHireJobManagerResp(object):
    info: GetHireJobManagerRespInfo = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 职位负责人


def _gen_get_hire_job_manager_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireJobManagerResp,
        scope="Hire",
        api="GetHireJobManager",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/jobs/:job_id/managers/:manager_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApplicationMessageDetailReq(object):
    app_id: str = attr.ib(default="", metadata={"req_type": "query"})  # 目标应用的 ID
    message_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # open_message_id
    time_start: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 起始时间戳（秒），时间跨度最长支持180天
    time_end: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 截止时间戳（秒），时间跨度最长支持180天
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，首次传空，非首次使用返回中的page_token
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小，默认为512，取值区间[1,1000]


@attr.s
class GetApplicationMessageDetailRespUsersRead(object):
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # open_id


@attr.s
class GetApplicationMessageDetailRespTarget(object):
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # open_id


@attr.s
class GetApplicationMessageDetailRespMessageType(object):
    pass


@attr.s
class GetApplicationMessageDetailRespChatType(object):
    pass


@attr.s
class GetApplicationMessageDetailResp(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # open_message_id
    chat_type: GetApplicationMessageDetailRespChatType = attr.ib(
        factory=lambda: GetApplicationMessageDetailRespChatType(),
        metadata={"req_type": "json"},
    )  # 聊天类型
    message_type: GetApplicationMessageDetailRespMessageType = attr.ib(
        factory=lambda: GetApplicationMessageDetailRespMessageType(),
        metadata={"req_type": "json"},
    )  # 消息类型
    nsent: int = attr.ib(default=0, metadata={"req_type": "json"})  # 总发送数
    target: GetApplicationMessageDetailRespTarget = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 发送目标用户列表，群聊为空
    nread: int = attr.ib(default=0, metadata={"req_type": "json"})  # 总阅读数
    users_read: GetApplicationMessageDetailRespUsersRead = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 已读用户列表
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多分页，当 has_more 为 true 时，会同时返回新的 page_token
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token


def _gen_get_application_message_detail_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApplicationMessageDetailResp,
        scope="Application",
        api="GetApplicationMessageDetail",
        method="POST",
        url="https://open.feishu.cn/open-apis/application/v1/app_message_detail",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
